@@ -17,7 +17,10 @@ import constructs._jsii
 import projen._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-prototyping-sdk/pipeline", "0.9.4", __name__[0:-6], "pipeline@0.9.4.jsii.tgz"
+    "@aws-prototyping-sdk/pipeline",
+    "0.10.1",
+    __name__[0:-6],
+    "pipeline@0.10.1.jsii.tgz",
 )
 
 __all__ = [
